@@ -1,7 +1,8 @@
 use crate::{
     bytes::{Cursor, Reader},
-    message::{RecordClass, RecordType},
-    InlineName, Result,
+    message::{ClassValue, TypeValue},
+    names::InlineName,
+    Result,
 };
 
 /// Query question.
@@ -14,9 +15,9 @@ pub struct Question {
     /// Domain name to query.
     pub qname: InlineName,
     /// Question type.
-    pub qtype: RecordType,
+    pub qtype: TypeValue,
     /// Question class.
-    pub qclass: RecordClass,
+    pub qclass: ClassValue,
 }
 
 impl Reader<Question> for Cursor<'_> {
